==> pipewire-docs-0.3.5-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a4828b5ffb309b2d8a985e0ee4fc80978",
"global_8h.html#a7c5ab037320ab252af6eb6eb1b85b0b9",
"impl-node_8c.html#a51569338546db3fa16325394364f752b",
"link_8h.html#a7859f6eb040fead1673d0214b83b445ba843c796704968af8538babd8f5c642e2",
"permission_8h_source.html",
"stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7",
"structpw__filter__events.html#a5a03c51cf03b2e8408ead88cc66b25cd",
"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-0.3.6-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a47e11e8e3cb9a31107f8f42308314b27",
"global_8h.html#a74a7902607d041b9ebea8ad223af7a2d",
"impl-node_8c.html#a47f2e62c0dbebc787052c165afcada0e",
"link_8h.html#a7859f6eb040fead1673d0214b83b445ba369af04b8025470a27c313640bbb4bc0",
"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b",
"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82",
"structpw__factory__methods.html#aa3d553e1352e95ecc6870f28cb98a5fe",
"structpw__protocol__marshal.html#a84d23417562653ce0c3f833914745b4b"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
